"use strict";
/**
 * 	SIMPLE-REDUX:
 *	It can interact with redux in a simple way: like arrays or like dictionaries.
    You can get the state like getDictionary(name) of getArray(name) and start working with it.
 */
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    Object.defineProperty(o, k2, { enumerable: true, get: function() { return m[k]; } });
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
var redux = __importStar(require("redux"));
var reduxDictionaries_1 = __importDefault(require("./state/redux/reduxDictionaries"));
var reduxArrays_1 = __importDefault(require("./state/redux/reduxArrays"));
var Array_1 = __importDefault(require("./state/Array"));
var Dictionary_1 = __importDefault(require("./state/Dictionary"));
/**
 *  Containts the state of the app.
 */
var state = {
    showInConsole: false,
    updatesCounter: 0,
    store: undefined,
    dictionaries: {},
    arrays: {},
};
/**
 * 	Throws an error if the store haven't been initialized.
 */
var verifyStoreCreated = function () {
    if (typeof state.store.getState !== 'function') {
        throw new Error('No se ha iniciado el estado.');
    }
};
/**
 * 	Return the store, if its created.
 */
var getStore = function getStore() {
    verifyStoreCreated();
    return state.store;
};
/**
 * 	Gets the store state: store.getState().
 */
var getState = function getState() {
    verifyStoreCreated();
    return state.store.getState();
};
/**
 *  If set TRUE, each change in the store will be displayes in the console.
 */
var setShowInConsole = function setShowInConsole(mustShow) {
    state.showInConsole = mustShow;
    return true;
};
/**
 *  Console logs the state, if specified.
 */
var consoleLogState = function () {
    if (!state.showInConsole) {
        return true;
    }
    state.updatesCounter += 1;
    console.log(state.updatesCounter, getState());
    return true;
};
/**
 *  Creates the store with the arrays and dictionaries established.
 */
var createStore = function (dictionaryNames, arrayNames) {
    var dictReducers = reduxDictionaries_1.default.createReducers(dictionaryNames);
    var arrayReducers = reduxArrays_1.default.createReducers(arrayNames);
    var reducers = Object.assign(dictReducers, arrayReducers);
    var combinedReducers = redux.combineReducers(reducers);
    state.store = redux.createStore(combinedReducers);
    reduxDictionaries_1.default.setStore(state.store);
    reduxArrays_1.default.setStore(state.store);
    state.store.subscribe(consoleLogState);
    return true;
};
/**
 * 	It initializes each array and dictionary.
 */
var createObjects = function (dictionaryNames, arrayNames) {
    dictionaryNames.forEach(function (dictionaryName) {
        state.dictionaries[dictionaryName] = new Dictionary_1.default(dictionaryName);
        return true;
    });
    arrayNames.forEach(function (arrayName) {
        if (typeof state.dictionaries[arrayName] !== 'undefined') {
            throw new Error("Redux object with name \"" + arrayName + "\" has already been declared.");
        }
        state.arrays[arrayName] = new Array_1.default(arrayName);
        return true;
    });
    return true;
};
/**
 * 	Returns the dictionary or the array by its name.
 */
var get = function get(name) {
    if (typeof state.dictionaries[name] !== 'undefined') {
        return state.dictionaries[name];
    }
    if (typeof state.arrays[name] === 'undefined') {
        throw new Error("Cannot find " + name + " in redux objects.");
    }
    return state.arrays[name];
};
/**
 * 	Returns the dictionary by its name.
 */
var getDictionary = function getDictionary(name) {
    verifyStoreCreated();
    if (typeof state.dictionaries[name] === 'undefined') {
        throw new Error("Cannot find dictionary " + name);
    }
    return state.dictionaries[name];
};
/**
 * 	Returns the array by its name.
 */
var getArray = function getArray(name) {
    verifyStoreCreated();
    if (typeof state.arrays[name] === 'undefined') {
        throw new Error("Cannot find array " + name);
    }
    return state.arrays[name];
};
/**
 * 	Starts the state creating a store with all the specified arrays and dictionaries.
 */
var startEmpty = function startEmpty(dictionaryNames, arrayNames) {
    createStore(dictionaryNames, arrayNames);
    createObjects(dictionaryNames, arrayNames);
    return true;
};
/**
 * 	Starts with initial state. Each array and dictionary should be given with a reasonable content.
 * 	For example, each array element must have an "id" property.
 */
var startWithState = function startWithState(dictionaries, arrays) {
    var dictionaryNames = Object.keys(dictionaries);
    var arrayNames = Object.keys(arrays);
    startEmpty(dictionaryNames, arrayNames);
    var tmpContent;
    dictionaryNames.forEach(function (name) {
        tmpContent = dictionaries[name];
        getDictionary(name).set(tmpContent);
    });
    arrayNames.forEach(function (name) {
        tmpContent = arrays[name];
        getArray(name).push(tmpContent);
    });
    return true;
};
/**
 * Suscribes a function to the store.
 * It's a proxy to store.subscribe(listener).
 */
var subscribe = function subscribe(listener) {
    getStore().subscribe(listener);
    return true;
};
module.exports = {
    get: get,
    getDictionary: getDictionary,
    getArray: getArray,
    getState: getState,
    getStore: getStore,
    startEmpty: startEmpty,
    setShowInConsole: setShowInConsole,
    startWithState: startWithState,
    subscribe: subscribe,
};
