declare type DictionaryContent = Record<string, any>;
declare class Dictionary {
    private _name;
    constructor(name: string);
    /**
     * Gets a copy of the dictionary content.
     */
    get(): object;
    /**
     *  Gets the different keys of the dictionary.
     */
    getKeys(): string[];
    /**
     * 	Gets how many keys the dictionary has.
     */
    count(): number;
    /**
     * Sets the different contents of the dictionary. It works like Object.assign.
     */
    set(contents: DictionaryContent): boolean;
    /**
     *  Sets a nested prop in the dictionary.
     *  Set {'prop1.subprop.subsubprop':value} will be like
     *  dictionary.prop1.subprop.subsubprop = value.
     *  Can also be called like ['prop1','subprop','subsubprop'].
     */
    deepSet(propertyPath: string | string[], value: any): boolean;
    /**
     *  Uses deepSet with many changes: {'prop1.subprop1.subsubprop1':1, 'prop2.subprop2':3}.
     *  Will change both properties in the state.
     */
    deepSetMany(changes: Record<string, any>): boolean;
    /**
     *  Merges the new content with the dictionary content (like lodash.merge).
     *  If you set to {name:{first, second},...others} the contents {name:third}, the result will have {name:{first, second, third}}.
     */
    merge(contents: DictionaryContent): boolean;
    /**
     * Removes (sets to undefined) the properties of the dictionary with the specified keys.
     */
    remove(keys: (number | string)[]): boolean;
    /**
     * Replace all the dictionary content with the new content (like erasing the content and setting the new content).
     */
    replace(content: DictionaryContent): boolean;
    /**
     * Empties the content of the dictionary. Its value will be {}.
     */
    empty(): boolean;
    /**
     *  Get the property path from a string: 'prop1.prop2.prop3' will become ['prop1','prop2','prop3'].
     */
    private _getDeepPropertyPath;
    /**
     *  Modifies the object creating the specified path.
     *  Assinging 'prop.subprop.subsubprop' = 3 to {}, will create: {prop:{subprop:{subsubprop:3}}}
     */
    private _deepSet;
}
export default Dictionary;
