/**
 * 	REDUX ARRAYS:
 * 	Its an interface to access different arrays in Redux.
 *  You can interact with a arrays just by its name.
 */
import ReduxObject from './ReduxObject';
declare type NewContent = Record<string, any> & {
    id: string | number;
};
declare type ArrayObject = NewContent & {
    index: number;
};
/**
 * 	REDUX ARRAYS:
 * 	Its an interface to access different arrays in Redux.
 *  You can interact with a arrays just by its name.
 */
declare class ReduxArrays extends ReduxObject {
    /**
     *  Creates the differents reducers to use in redux.
     *  Results: {name:reducer, name:reducer, name:reducer}.
     */
    createReducers(arrayNames: string[]): any;
    /**
     * Push the different contents to the array. It works like array.push.
     */
    push(arrayName: string, contents: NewContent[]): boolean;
    /**
     * Unshift the different contents to the array. It works like array.unshift.
     */
    unshift(arrayName: string, contents: NewContent[]): boolean;
    /**
     * Inject the different contents to the array in the specified index. It works like array.splice(index, 0, newArray).
     */
    inject(arrayName: string, index: number, contents: NewContent[]): boolean;
    /**
     * 	Get the array state by its name.
     */
    get(arrayName: string): ArrayObject[];
    /**
     * Updates the contents of the array which have the specified Ids.
     * The contents are modified like Object.assign.
     */
    update(arrayName: string, ids: (string | number)[], changes: any): boolean;
    /**
     *  Removes the contents from the array which have the specified Ids.
     */
    remove(arrayName: string, ids: (string | number)[]): boolean;
    /**
     * 	Replace the whole array with a new array. It's like erasing the array and pushing the new content.
     */
    replace(arrayName: string, content: NewContent[]): boolean;
    /**
     * Empties the array.
     */
    empty(arrayName: string): boolean;
}
declare const _default: ReduxArrays;
export default _default;
