"use strict";
/**
 * 	REDUX ARRAYS:
 * 	Its an interface to access different arrays in Redux.
 *  You can interact with a arrays just by its name.
 */
var __extends = (this && this.__extends) || (function () {
    var extendStatics = function (d, b) {
        extendStatics = Object.setPrototypeOf ||
            ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
            function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
        return extendStatics(d, b);
    };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
var actions_1 = __importDefault(require("./reduxArrays/actions"));
var reducer_1 = __importDefault(require("./reduxArrays/reducer"));
var ReduxObject_1 = __importDefault(require("./ReduxObject"));
/**
 * 	REDUX ARRAYS:
 * 	Its an interface to access different arrays in Redux.
 *  You can interact with a arrays just by its name.
 */
var ReduxArrays = /** @class */ (function (_super) {
    __extends(ReduxArrays, _super);
    function ReduxArrays() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    /**
     *  Creates the differents reducers to use in redux.
     *  Results: {name:reducer, name:reducer, name:reducer}.
     */
    ReduxArrays.prototype.createReducers = function (arrayNames) {
        var reducers = {};
        arrayNames.forEach(function (name) {
            reducers[name] = reducer_1.default(name);
        });
        return reducers;
    };
    /**
     * Push the different contents to the array. It works like array.push.
     */
    ReduxArrays.prototype.push = function (arrayName, contents) {
        var action = actions_1.default.push(arrayName, contents);
        return this.dispatch(action);
    };
    /**
     * Unshift the different contents to the array. It works like array.unshift.
     */
    ReduxArrays.prototype.unshift = function (arrayName, contents) {
        var action = actions_1.default.unshift(arrayName, contents);
        return this.dispatch(action);
    };
    /**
     * Inject the different contents to the array in the specified index. It works like array.splice(index, 0, newArray).
     */
    ReduxArrays.prototype.inject = function (arrayName, index, contents) {
        var action = actions_1.default.inject(arrayName, index, contents);
        return this.dispatch(action);
    };
    /**
     * 	Get the array state by its name.
     */
    ReduxArrays.prototype.get = function (arrayName) {
        var state = this.getStore().getState();
        return state[arrayName];
    };
    /**
     * Updates the contents of the array which have the specified Ids.
     * The contents are modified like Object.assign.
     */
    ReduxArrays.prototype.update = function (arrayName, ids, changes) {
        var action = actions_1.default.update(arrayName, ids, changes);
        return this.dispatch(action);
    };
    /**
     *  Removes the contents from the array which have the specified Ids.
     */
    ReduxArrays.prototype.remove = function (arrayName, ids) {
        var action = actions_1.default.delete(arrayName, ids);
        return this.dispatch(action);
    };
    /**
     * 	Replace the whole array with a new array. It's like erasing the array and pushing the new content.
     */
    ReduxArrays.prototype.replace = function (arrayName, content) {
        var action = actions_1.default.replace(arrayName, content);
        return this.dispatch(action);
    };
    /**
     * Empties the array.
     */
    ReduxArrays.prototype.empty = function (arrayName) {
        var action = actions_1.default.empty(arrayName);
        return this.dispatch(action);
    };
    return ReduxArrays;
}(ReduxObject_1.default));
exports.default = new ReduxArrays();
