/**
 * 	REDUX ARRAY ACTION CREATOR:
 * 	This script creates the different actions the array reducer will need.
 */
interface Action {
    type: string;
    payload: any;
}
declare type ArrayObject = Record<string, any> & {
    id: string | number;
};
declare const _default: {
    /**
     * 	Set the different contents in the array.
     */
    set: (arrayName: string, contents: ArrayObject[]) => Action;
    /**
     * 	Adds the different contents at the end of the array. Works like array.push.
     */
    push: (arrayName: string, contents: ArrayObject[]) => Action;
    /**
     * 	Adds the different contents at the beggining of the array. Works like array.unshift.
     */
    unshift: (arrayName: string, contents: ArrayObject[]) => Action;
    /**
     * 	Adds the different contents in the specified index of the array.
     */
    inject: (arrayName: string, index: number, contents: ArrayObject[]) => Action;
    /**
     * 	Updates the objects in the array with the specified Ids.
     */
    update: (arrayName: string, ids: (string | number)[], changes: object) => Action;
    /**
     * 	Deletes the objects in the array with the specified ids.
     */
    delete: (arrayName: string, ids: (string | number)[]) => Action;
    /**
     * 	Replace array content.
     */
    replace: (arrayName: string, content: ArrayObject[]) => Action;
    /**
     * 	Empty the array.
     */
    empty: (arrayName: string) => Action;
};
export default _default;
