"use strict";
/**
 * 	REDUX ARRAY ACTION CREATOR:
 * 	This script creates the different actions the array reducer will need.
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.default = {
    /**
     * 	Set the different contents in the array.
     */
    set: function (arrayName, contents) {
        return {
            type: "ARRAY_SET_" + arrayName,
            payload: contents,
        };
    },
    /**
     * 	Adds the different contents at the end of the array. Works like array.push.
     */
    push: function (arrayName, contents) {
        return {
            type: "ARRAY_PUSH_" + arrayName,
            payload: contents,
        };
    },
    /**
     * 	Adds the different contents at the beggining of the array. Works like array.unshift.
     */
    unshift: function (arrayName, contents) {
        return {
            type: "ARRAY_UNSHIFT_" + arrayName,
            payload: contents,
        };
    },
    /**
     * 	Adds the different contents in the specified index of the array.
     */
    inject: function (arrayName, index, contents) {
        return {
            type: "ARRAY_INJECT_" + arrayName,
            payload: { index: index, contents: contents },
        };
    },
    /**
     * 	Updates the objects in the array with the specified Ids.
     */
    update: function (arrayName, ids, changes) {
        return {
            type: "ARRAY_UPDATE_" + arrayName,
            payload: {
                ids: ids,
                changes: changes,
            },
        };
    },
    /**
     * 	Deletes the objects in the array with the specified ids.
     */
    delete: function (arrayName, ids) {
        return {
            type: "ARRAY_DELETE_" + arrayName,
            payload: ids,
        };
    },
    /**
     * 	Replace array content.
     */
    replace: function (arrayName, content) {
        return {
            type: "ARRAY_REPLACE_" + arrayName,
            payload: content,
        };
    },
    /**
     * 	Empty the array.
     */
    empty: function (arrayName) {
        return {
            type: "ARRAY_EMPTY_" + arrayName,
            payload: {},
        };
    },
};
