"use strict";
/**
 * 	REDUX DICTIONARIES:
 * 	Its an interface to access different dictionaries in Redux.
 *  You can interact with a dictionary just by its name.
 */
var __extends = (this && this.__extends) || (function () {
    var extendStatics = function (d, b) {
        extendStatics = Object.setPrototypeOf ||
            ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
            function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
        return extendStatics(d, b);
    };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
var actions_1 = __importDefault(require("./reduxDictionaries/actions"));
var reducer_1 = __importDefault(require("./reduxDictionaries/reducer"));
var ReduxObject_1 = __importDefault(require("./ReduxObject"));
/**
 * 	Its an interface to access different dictionaries in Redux.
 *  You can interact with a dictionary just by its name.
 */
var ReduxDictionaries = /** @class */ (function (_super) {
    __extends(ReduxDictionaries, _super);
    function ReduxDictionaries() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    /**
     * 	Creates the differents reducers to use in redux.
     *  Results: {name:reducer, name:reducer, name:reducer}.
     */
    ReduxDictionaries.prototype.createReducers = function (dictionaryNames) {
        var reducers = {};
        dictionaryNames.forEach(function (name) {
            reducers[name] = reducer_1.default(name);
        });
        return reducers;
    };
    /**
     * 	Set the different contents to the specified dictionary.
     *  it works like Object.assign.
     */
    ReduxDictionaries.prototype.set = function (dictionaryName, contents) {
        var action = actions_1.default.set(dictionaryName, contents);
        return this.dispatch(action);
    };
    /**
     * 	Set the different contents to the specified dictionary by merging.
     *  it works like lodash.merge.
     */
    ReduxDictionaries.prototype.merge = function (dictionaryName, contents) {
        var action = actions_1.default.merge(dictionaryName, contents);
        return this.dispatch(action);
    };
    /**
     * 	Get the dictionary state by its name.
     */
    ReduxDictionaries.prototype.get = function (dictionaryName) {
        var state = this.getStore().getState();
        return state[dictionaryName];
    };
    /**
     * 	Removes the elements from the dictionary with the specified keys.
     */
    ReduxDictionaries.prototype.remove = function (dictionaryName, keys) {
        var action = actions_1.default.delete(dictionaryName, keys);
        return this.dispatch(action);
    };
    /**
     *  Replace the dictionary content.
     */
    ReduxDictionaries.prototype.replace = function (dictionaryName, content) {
        var action = actions_1.default.replace(dictionaryName, content);
        return this.dispatch(action);
    };
    return ReduxDictionaries;
}(ReduxObject_1.default));
exports.default = new ReduxDictionaries();
