"use strict";
/**
 *  REDUCER FACTORY:
 * 	It creates the reducers for the dictionaries.
 */
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
Object.defineProperty(exports, "__esModule", { value: true });
var lodash_1 = require("lodash");
/**
 *  Checks if the content sent is valid. (an object with keys).
 *  Throws an error if it's not.
 */
var checkValidContent = function checkValidContent(content) {
    var contentType = typeof content;
    if (content === null ||
        contentType === 'bigint' ||
        contentType === 'boolean' ||
        contentType === 'number' ||
        contentType === 'function' ||
        contentType === 'string' ||
        contentType === 'symbol' ||
        contentType === 'undefined' ||
        Array.isArray(content)) {
        throw new Error('The content of the dictionary must be an object.');
    }
    return true;
};
/**
 * 	Changes the dictionary content. It works likes Object.assign.
 */
var set = function (state, newContent) {
    checkValidContent(newContent);
    var previousState = lodash_1.cloneDeep(state);
    var clonedNewContent = lodash_1.cloneDeep(newContent);
    var newState = __assign(__assign({}, previousState), clonedNewContent);
    return newState;
};
/**
 * 	Changes the dictionary content. It works likes lodash merge function.
 */
var setWithMerge = function (state, newContent) {
    checkValidContent(newContent);
    var previousState = lodash_1.cloneDeep(state);
    var clonedNewContent = lodash_1.cloneDeep(newContent);
    return lodash_1.merge(previousState, clonedNewContent);
};
/**
 * 	Removes the content with the specified keys.
 */
var remove = function (state, keys) {
    var modifiedState = lodash_1.cloneDeep(state);
    keys.forEach(function (key) { return delete modifiedState[key]; });
    return modifiedState;
};
/**
 * 	Replaces the dictionary content.
 */
var replace = function (newContent) {
    checkValidContent(newContent);
    return lodash_1.cloneDeep(newContent);
};
/**
 *  Creates a reducer for a dictionary with the specified name.
 */
var createReducer = function (dictionaryName) {
    var initialState = {};
    return function reducer(state, action) {
        if (state === void 0) { state = initialState; }
        switch (action.type) {
            case "DICT_SET_" + dictionaryName:
                return set(state, action.payload);
            case "DICT_MERGE_" + dictionaryName:
                return setWithMerge(state, action.payload);
            case "DICT_DELETE_" + dictionaryName:
                return remove(state, action.payload);
            case "DICT_REPLACE_" + dictionaryName:
                return replace(action.payload);
            default:
                return state;
        }
    };
};
exports.default = createReducer;
